@@ -1,6 +1,7 @@
 import os.path as osp
 import re
 import shutil
+from pathlib import Path
 
 import yaml
 from loguru import logger
@@ -8,39 +9,19 @@ from loguru import logger
 here = osp.dirname(osp.abspath(__file__))
 
 
-def update_dict(target_dict, new_dict, validate_item=None):
+def _update_dict(target_dict, new_dict, validate_item=None):
     for key, value in new_dict.items():
         if validate_item:
             validate_item(key, value)
         if key not in target_dict:
-            logger.warning(f"Skipping unexpected key in config: {key}")
-            continue
+            raise ValueError(f"Unexpected key in config: {key}")
         if isinstance(target_dict[key], dict) and isinstance(value, dict):
-            update_dict(target_dict[key], value, validate_item=validate_item)
+            _update_dict(target_dict[key], value, validate_item=validate_item)
         else:
             target_dict[key] = value
 
 
-# -----------------------------------------------------------------------------
-
-
-def _get_default_config_and_create_labelmerc():
-    config_file = osp.join(here, "default_config.yaml")
-    with open(config_file) as f:
-        config = yaml.safe_load(f)
-
-    # save default config to ~/.labelmerc
-    user_config_file = osp.join(osp.expanduser("~"), ".labelmerc")
-    if not osp.exists(user_config_file):
-        try:
-            shutil.copy(config_file, user_config_file)
-        except Exception:
-            logger.warning(f"Failed to save config: {user_config_file}")
-
-    return config
-
-
-def validate_config_item(key, value):
+def _validate_config_item(key, value):
     if key == "validate_label" and value not in [None, "exact"]:
         raise ValueError(f"Unexpected value for config key 'validate_label': {value}")
     if key == "shape_color" and value not in [None, "auto", "manual"]:
@@ -73,22 +54,31 @@ def _migrate_config_from_file(config_from_yaml: dict) -> None:
         config_from_yaml["ai"]["default"] = model_name_new
 
 
-def get_config(config_file_or_yaml=None, config_from_args=None):
-    # 1. default config
-    config = _get_default_config_and_create_labelmerc()
+def get_user_config_file(create_if_missing: bool = True) -> str:
+    user_config_file: str = osp.join(osp.expanduser("~"), ".labelmerc")
+    if not osp.exists(user_config_file) and create_if_missing:
+        try:
+            shutil.copy(osp.join(here, "default_config.yaml"), user_config_file)
+        except Exception:
+            logger.warning("Failed to save config: {!r}", user_config_file)
+    return user_config_file
 
-    # 2. specified as file or yaml
-    if config_file_or_yaml is not None:
-        config_from_yaml = yaml.safe_load(config_file_or_yaml)
-        if not isinstance(config_from_yaml, dict):
-            with open(config_from_yaml) as f:
-                logger.info(f"Loading config file from: {config_from_yaml}")
-                config_from_yaml = yaml.safe_load(f)
-        _migrate_config_from_file(config_from_yaml=config_from_yaml)
-        update_dict(config, config_from_yaml, validate_item=validate_config_item)
 
-    # 3. command line argument or specified config file
-    if config_from_args is not None:
-        update_dict(config, config_from_args, validate_item=validate_config_item)
+def load_config(config_file: Path | None, config_overrides: dict) -> dict:
+    config: dict
+    with open(osp.join(here, "default_config.yaml")) as f:
+        config = yaml.safe_load(f)
+
+    if config_file is not None:
+        with open(config_file) as f:
+            config_from_yaml = yaml.safe_load(f)
+        if isinstance(config_from_yaml, dict):
+            _migrate_config_from_file(config_from_yaml=config_from_yaml)
+            _update_dict(config, config_from_yaml, validate_item=_validate_config_item)
+
+    _update_dict(config, config_overrides, validate_item=_validate_config_item)
+
+    if not config["labels"] and config["validate_label"]:
+        raise ValueError("labels must be specified when validate_label is enabled")
 
     return config
