@@ -1,5 +1,6 @@
+from ._ai_assisted_annotation_widget import AiAssistedAnnotationWidget
+from ._ai_text_to_annotation_widget import AiTextToAnnotationWidget
 from ._status import StatusStats
-from .ai_prompt_widget import AiPromptWidget
 from .brightness_contrast_dialog import BrightnessContrastDialog
 from .canvas import Canvas
 from .download import download_ai_model
